var interfaceplplot_1_1core_1_1plplotjavacConstants =
[
    [ "BASE_CONT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a03e64e4ab90be54223c1e0ffb4da34b5", null ],
    [ "DRAW_LINEX", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a78186e922b4c0587058b89df782d5ead", null ],
    [ "DRAW_LINEXY", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a6b221b57c0b722bcca7d18195666d5fb", null ],
    [ "DRAW_LINEY", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a57935553f9eed159d7071c06cdf27e18", null ],
    [ "DRAW_SIDES", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a1045c9467abda926a1710b7103962e9b", null ],
    [ "FACETED", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ad9704a54d0cce3496ac15f537f6faa77", null ],
    [ "GRID_CSA", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ae64ff93e7451043c87595b1f57578dc6", null ],
    [ "GRID_DTLI", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a34b6315c9ae7a36da1290ccadd7202f3", null ],
    [ "GRID_NNAIDW", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#aa1b79f0206722f1c4a13c357ab3d2e35", null ],
    [ "GRID_NNI", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a971b5a9980787f3b5aa39318ed8f4349", null ],
    [ "GRID_NNIDW", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ab98f0ef378fda8360117e1f55df273ec", null ],
    [ "GRID_NNLI", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a3eae2031bbcb11d266efd99b44adcce1", null ],
    [ "jPLFLTArray", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a92daefbe46769fd61eb907b6f9ab5932", null ],
    [ "jPLFLTbracket", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a14c6573f4a10348b94021ad53a787fc9", null ],
    [ "jPLFLTbracket2", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a541e25b949e81770d55f9f1eb93d0ba0", null ],
    [ "MAG_COLOR", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a61c4c5d2f73b3aec574b48f40bf6f544", null ],
    [ "MESH", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#aac37eb4faa5c5377e1c349b44cd519b8", null ],
    [ "ONEW2B", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a38be4ac9a54000d51e4693bb5eedddf8", null ],
    [ "ONEW2D", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a20630324890f6d0e462b477cd861babc", null ],
    [ "PL_BIN_CENTRED", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a3be0f4c46e5e01a83bc70a63ac52968a", null ],
    [ "PL_BIN_DEFAULT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#afe6b05d7e9aad8169488231d70cd69b4", null ],
    [ "PL_BIN_NOEMPTY", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#aa81651b2b9baf39e0ce55c241f1363a1", null ],
    [ "PL_BIN_NOEXPAND", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a39fc6d77fd6522e2cc631cf267a308a5", null ],
    [ "PL_COLORBAR_BACKGROUND", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ac05c9cfbc0326cd551ad877952a69d4b", null ],
    [ "PL_COLORBAR_BOUNDING_BOX", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a698891b1f8a9d0ae7127077fdee8b429", null ],
    [ "PL_COLORBAR_CAP_HIGH", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a84596933f87e688b61657b0f1e9e454f", null ],
    [ "PL_COLORBAR_CAP_LOW", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ad7be0bb9e77c63312ec90419e9412740", null ],
    [ "PL_COLORBAR_CAP_NONE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a10d36d3f588fa596770805bf5837525d", null ],
    [ "PL_COLORBAR_GRADIENT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ad0b2997f0f27998661ab5c90deb72b09", null ],
    [ "PL_COLORBAR_IMAGE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#af4677a53b6cedb2acd21ed6b22072b39", null ],
    [ "PL_COLORBAR_LABEL_BOTTOM", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ab5885e68380114bc15b04432535d8c56", null ],
    [ "PL_COLORBAR_LABEL_LEFT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a9643f7e11e2a4a04d21e10d6cea89f06", null ],
    [ "PL_COLORBAR_LABEL_RIGHT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a163c3e53ea9e5b76562304fbf3c85973", null ],
    [ "PL_COLORBAR_LABEL_TOP", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a7ced24ee89a620026c2ab2a1363da413", null ],
    [ "PL_COLORBAR_ORIENT_BOTTOM", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a9bc673cda415d176b734c12026a05c84", null ],
    [ "PL_COLORBAR_ORIENT_LEFT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a110d822a10ba8f5eeee1f0ef3aad4d7f", null ],
    [ "PL_COLORBAR_ORIENT_RIGHT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a846f4fe1db0b8bf2147954c36706d899", null ],
    [ "PL_COLORBAR_ORIENT_TOP", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ac25410027dee618cdf7f1042085b06de", null ],
    [ "PL_COLORBAR_SHADE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ae85d0561ae22407c00ff511f79684944", null ],
    [ "PL_COLORBAR_SHADE_LABEL", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a8e0158c4ea4ce37838a49469d57c98d9", null ],
    [ "PL_DRAWMODE_DEFAULT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#aca9eede3795cce82e34c2dc882b8254f", null ],
    [ "PL_DRAWMODE_REPLACE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a06f09539166da05999b4301c26c8656c", null ],
    [ "PL_DRAWMODE_UNKNOWN", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a53d40058b2169111a03e5787225c4eb4", null ],
    [ "PL_DRAWMODE_XOR", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a1a313b5ab49944633c98c75605268bb3", null ],
    [ "PL_FCI_BOLD", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#afabc9391c694668a6ade5030668c8a52", null ],
    [ "PL_FCI_FAMILY", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a59d24eb5c6af659ff4c0a79bdc82e346", null ],
    [ "PL_FCI_HEXDIGIT_MASK", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a8f49fb97371a2e5935cba71110f1e2f2", null ],
    [ "PL_FCI_HEXPOWER_IMPOSSIBLE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ae3ea0330d2e7604ad861b4e0b8cf3931", null ],
    [ "PL_FCI_HEXPOWER_MASK", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#abc2996af1e5a9f08dfb4dce63615b711", null ],
    [ "PL_FCI_IMPOSSIBLE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a098ae6dd3a3dc96846912ce7358fac4e", null ],
    [ "PL_FCI_ITALIC", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a3e15f3c9b1f88849feccb3ee95480cb7", null ],
    [ "PL_FCI_MARK", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a63b7f5396f33b7418ad7edb0945cbf39", null ],
    [ "PL_FCI_MEDIUM", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a6904daf90e52d061a7879e68c1c43b1f", null ],
    [ "PL_FCI_MONO", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ade74c380ddee66be14b9615bb89c7acf", null ],
    [ "PL_FCI_OBLIQUE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a6f27812f78507914b6ff91174aa78745", null ],
    [ "PL_FCI_SANS", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#aabb7236bbe0bf4335f884c2116c594f4", null ],
    [ "PL_FCI_SCRIPT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#aeeaf3f50daadf84971bc416ddc0df832", null ],
    [ "PL_FCI_SERIF", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a9c8fe725813566797eef49eb3ae40822", null ],
    [ "PL_FCI_STYLE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#af43b1c3c2fd6c07e56597264d132758b", null ],
    [ "PL_FCI_SYMBOL", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ad29f228e6a3485ffe123daba92b37400", null ],
    [ "PL_FCI_UPRIGHT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a42e4f478b10f25731ad3fb92a2da58f5", null ],
    [ "PL_FCI_WEIGHT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ae92f5c357d1750c16e601c8edc878ed0", null ],
    [ "PL_HIST_DEFAULT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ae8192d10fff2e2d29d158ec66211924d", null ],
    [ "PL_HIST_IGNORE_OUTLIERS", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a0bcc4530875c8bbd3444f90604bc6baa", null ],
    [ "PL_HIST_NOEMPTY", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a0d88da24dd119e53e8d9b85dbff416ed", null ],
    [ "PL_HIST_NOEXPAND", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a3c4f07173d48c831bfcfa855ddfea9fd", null ],
    [ "PL_HIST_NOSCALING", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a4a116228857303a271439a2f6eb816d5", null ],
    [ "PL_LEGEND_BACKGROUND", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a483ade22f9d0f98cddb5f13c9878509d", null ],
    [ "PL_LEGEND_BOUNDING_BOX", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a75767e431a05e5cca461e74c5010a84a", null ],
    [ "PL_LEGEND_COLOR_BOX", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ae84bb5d19432ce5f49e40cb433ac5271", null ],
    [ "PL_LEGEND_LINE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a119c088b812db8bc4e3fa539eb1ae80a", null ],
    [ "PL_LEGEND_NONE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a5cf6bb0a2c7739fe15def2ec694b4045", null ],
    [ "PL_LEGEND_ROW_MAJOR", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a4f7a7593921610fb39a4a356523571ce", null ],
    [ "PL_LEGEND_SYMBOL", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a295f9ce82297b9e059f837aa0d5233ee", null ],
    [ "PL_LEGEND_TEXT_LEFT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a372fa007de650d02d796c18a07cb756b", null ],
    [ "PL_MAXKEY", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ad15d5f9bf109f7555295e39aadade3bc", null ],
    [ "PL_MAXWINDOWS", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ab0a9647c3fd90a30578def97ea9ae320", null ],
    [ "PL_NOTSET", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a5d1af14d35b89e0d05a293a460e9c951", null ],
    [ "PL_OPT_ARG", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a8a581f476406cee6e1cf763abdac2968", null ],
    [ "PL_OPT_BOOL", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ade800d5bcf2d2efc3400d6bda9071a86", null ],
    [ "PL_OPT_DISABLED", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#adb8625072ec24f180be5e4263e8d0b22", null ],
    [ "PL_OPT_ENABLED", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#af6212de68258285761d48e4f3f0982f5", null ],
    [ "PL_OPT_FLOAT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a3afae2d3f1d4bc14f3ddf7037da991ab", null ],
    [ "PL_OPT_FUNC", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a05e08dd76f444ede52c7c0a40f198583", null ],
    [ "PL_OPT_INT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a192cf4d3a473b986680473f77bb9570c", null ],
    [ "PL_OPT_INVISIBLE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a16dd2ce83ff4ce109a0473e5a38273b0", null ],
    [ "PL_OPT_NODELETE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a8250be8bd4d41df23667a27401b163c7", null ],
    [ "PL_OPT_STRING", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a0da0c29abcaa26cc1a86ce41ef3b724f", null ],
    [ "PL_PARSE_FULL", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ab1725ba177924e6cb6a016c45c7881a0", null ],
    [ "PL_PARSE_NODASH", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a861e7953df8c2c4a97d47c91dc5ad7df", null ],
    [ "PL_PARSE_NODELETE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a9d6d6ecf6f0ed81e1facf44da4a26835", null ],
    [ "PL_PARSE_NOPROGRAM", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a4db7096fb0d1598122b0d3c3c8ced408", null ],
    [ "PL_PARSE_OVERRIDE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a4d3a27e1d8c303186706e9d4f5ff4bdc", null ],
    [ "PL_PARSE_PARTIAL", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#af687de3fe0a9a60b52d79093ce2972b8", null ],
    [ "PL_PARSE_QUIET", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ae3a120276c9a6c072dc7066aa181b73f", null ],
    [ "PL_PARSE_SHOWALL", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ad23d6b7ee02b187720473a7679482dc1", null ],
    [ "PL_PARSE_SKIP", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a8d4b490b3cc2e2b41149e5fd5cd9c295", null ],
    [ "PL_POSITION_BOTTOM", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a88cd3bc83aa2ee6f346b2131588c7dea", null ],
    [ "PL_POSITION_INSIDE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a8651cde2ce5b29f672cc36bcea9fa2a2", null ],
    [ "PL_POSITION_LEFT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ad4aed695def68e2b7e682ce615f7a5db", null ],
    [ "PL_POSITION_OUTSIDE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ab84eea5b7fc6984ca8e3ea1710b2dcb0", null ],
    [ "PL_POSITION_RIGHT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a6ec613fbe3e44f304bae065434d07d6b", null ],
    [ "PL_POSITION_SUBPAGE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a8b4b5d74000f75b8914c5acbd7ef4f5a", null ],
    [ "PL_POSITION_TOP", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a85538d56320b89da9e78530cec777fc8", null ],
    [ "PL_POSITION_VIEWPORT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ae42fcce479388ec313bdd5da5f7a6008", null ],
    [ "PL_X_AXIS", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#af435600551f03028e33b993c101d4165", null ],
    [ "PL_Y_AXIS", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#aaf1d2e471f3d12edcdf5591a2d648512", null ],
    [ "PL_Z_AXIS", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a1b45921af31fd7cb57084f2204ba4483", null ],
    [ "PLESC_ALLOC_NCOL", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a41fc6eb2fa8cba796619bd3e3b2eed9d", null ],
    [ "PLESC_APPEND_BUFFER", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#abcc96efec5c065d14c392acaaae87333", null ],
    [ "PLESC_ARC", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a7de1115c29d36dec0a1108536a8b91be", null ],
    [ "PLESC_BEGIN_TEXT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a5d25cb29f74a384031210a1fbad445db", null ],
    [ "PLESC_CLEAR", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#abba9d46462fe272a1579e3ee0fdaf77a", null ],
    [ "PLESC_CONTROL_CHAR", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a477409f96977748cd2ad21927637da3c", null ],
    [ "PLESC_DASH", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#af61f23f5bf0856728f1babe70e509b3c", null ],
    [ "PLESC_DEV2PLCOL", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a6ed7a5ad3cddfe0e9e981a03114c20c8", null ],
    [ "PLESC_DEVINIT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a86ceffd532405f35c4397c362fb746c9", null ],
    [ "PLESC_DI", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a0227ec7e9c2164d1e23a6af980b74a7a", null ],
    [ "PLESC_DOUBLEBUFFERING", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a5ad3b2460faecc59470ebc9d544ad0d6", null ],
    [ "PLESC_DOUBLEBUFFERING_DISABLE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a7b8c84534f588218a48eb1c5d1f2a54d", null ],
    [ "PLESC_DOUBLEBUFFERING_ENABLE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a938b85753895312220dc3a6e005bc13c", null ],
    [ "PLESC_DOUBLEBUFFERING_QUERY", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a18be416f25fbeb0691cd18cbbf283afe", null ],
    [ "PLESC_EH", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a6c3071977bc8efc1eb7367e3b6013c37", null ],
    [ "PLESC_END_RASTERIZE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ab2ee1d0efee3511703f2254b4877cab9", null ],
    [ "PLESC_END_TEXT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#aad130d9de5986f6dc8994a0db4e0349b", null ],
    [ "PLESC_EXPOSE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a732121025b156cc645cbebb040a811ae", null ],
    [ "PLESC_FILL", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#aa347d6a6d94d07b92bb198a0ac3aa812", null ],
    [ "PLESC_FIXASPECT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#af96ea44327119a2cbcdcfb2020cc12d9", null ],
    [ "PLESC_FLUSH", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a36f56817abcb9a8c7ce7f552fe666d06", null ],
    [ "PLESC_FLUSH_REMAINING_BUFFER", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#af10fee918893745015482a2334d2cd4e", null ],
    [ "PLESC_GETBACKEND", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a3ecc3541843fc56aced4664dce5698e2", null ],
    [ "PLESC_GETC", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ad109110bac666c1f71fdfa10bf70fc3c", null ],
    [ "PLESC_GRADIENT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a603e56e9a72637c930e2f275e8efa84b", null ],
    [ "PLESC_GRAPH", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a31780bd117b3f3c455355457ad250dad", null ],
    [ "PLESC_HAS_TEXT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#aa4be664bf8dd2979b3d61165fbd1cd03", null ],
    [ "PLESC_IMAGE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a9aafbc1ffdb08e134ea4a627bc5926e6", null ],
    [ "PLESC_IMAGEOPS", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#af6cd18df87f8c8ff9daba8c228190397", null ],
    [ "PLESC_IMPORT_BUFFER", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#aa9e45a23dd10b600a011f24bd6e04a33", null ],
    [ "PLESC_MODEGET", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#af058f8855fc78d548a5ab4f450837bed", null ],
    [ "PLESC_MODESET", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#abe5beb50d0a8723f9ae872b50b998b9b", null ],
    [ "PLESC_PL2DEVCOL", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a82c99e81b3be07f487e1eb34f5208d13", null ],
    [ "PLESC_REDRAW", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a3075a5b122c516e88e39e0ef161e5ce3", null ],
    [ "PLESC_RESIZE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#aa19a5b355dc6d1028b9ebb64a1dd5ae0", null ],
    [ "PLESC_SET_COMPRESSION", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ad28178144f538b1318fbc25cfc180d5e", null ],
    [ "PLESC_SET_LPB", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a06effe640e63bcae7abbfadba895c173", null ],
    [ "PLESC_SET_RGB", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a9db7781fac4d5945ea690b2db1b6264b", null ],
    [ "PLESC_SETBGFG", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a8380b25db65330bcc4b6087ba5a371ca", null ],
    [ "PLESC_START_RASTERIZE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a03ae7b3b08d865fce26b5d0e69a73e89", null ],
    [ "PLESC_SWIN", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#aab97e835749eab370fbb8b250638dcdd", null ],
    [ "PLESC_TEXT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a72853a59a3f3f3e830bc301d9df78021", null ],
    [ "PLESC_TEXT_CHAR", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a7c1426078dc61733b08261c39fbb43e2", null ],
    [ "PLESC_XORMOD", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ac3aee634f08a19eb41e9812596169f75", null ],
    [ "PLSWIN_DEVICE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#af7af96a45b3b9fc259a6eea2f5a52116", null ],
    [ "PLSWIN_WORLD", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a901c91a405506e3ce5d82858ede5549d", null ],
    [ "PLTEXT_BACKCHAR", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a54480bb7641605b6bc84aaa092786240", null ],
    [ "PLTEXT_FONTCHANGE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a8ef0efcdbe7747c349df66d1f8ee6b78", null ],
    [ "PLTEXT_OVERLINE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a11f525b2ca2bd216dd1c5cdac54f1945", null ],
    [ "PLTEXT_SUBSCRIPT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a663894df6ed9e719c80e0714bd5fefe8", null ],
    [ "PLTEXT_SUPERSCRIPT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a61b716b8bb9fe1964621dbdee8a45f7c", null ],
    [ "PLTEXT_UNDERLINE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a2bad1b3a580963c88454e3d64e8be9de", null ],
    [ "SURF_CONT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ad4a9643983348bd86607eac153651028", null ],
    [ "TOP_CONT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ac7cdabb7b04030b85f33a464b62b63d0", null ],
    [ "ZEROW2B", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a1ef09742695ba6f4cd9120c3a2d21c47", null ],
    [ "ZEROW2D", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ae06301ae05d5eeba3b9db261d4e20335", null ]
];